library(tidyverse)

surveys_complete <- read_csv("./data/portal_data_joined.csv") %>% 
  filter(!is.na(weight),
         !is.na(hindfoot_length),
         !is.na(sex))

surveys_complete

## Extract the most common species_id
species_counts <- surveys_complete %>%
  count(species_id) %>%
  filter(n >= 50)

## Only keep the most common species
surveys_complete <- surveys_complete %>%
  filter(species_id %in% species_counts$species_id)

surveys_complete

write_csv(surveys_complete, "./data/surveys_complete.csv")

## Visualisation et interpretations
library(ggplot2)

ggplot(data = surveys_complete,
       mapping = aes(x = weight, 
                     y = hindfoot_length)) + 
  geom_point()

ggplot(surveys_complete,
       aes(x = weight,
           y = hindfoot_length)) +
  geom_point()

p <- ggplot(surveys_complete,
            aes(x = weight,
                y = hindfoot_length))

p + geom_point()
  
p + geom_point(alpha = 0.1)

library(hexbin)
p + geom_hex()

p + geom_point(alpha = 0.1, 
               colour = "blue")

p + geom_point(alpha = 0.5, 
               aes(colour = species_id))

ggplot(surveys_complete,
       aes(x = weight,
           y = hindfoot_length,
           colour = species_id)) +
  geom_point()


## Use what you just learned to create a 
## scatter plot of weight 
## over species_id with the plot types 
## showing in different colors. 
## Is this a good way to show this type of data?

ggplot(surveys_complete,
       aes(x = species_id,
           y = weight,
           colour = plot_type)) +
  geom_point()


ggplot(surveys_complete,
       aes(x = species_id,
           y = weight)) +
  geom_boxplot()

ggplot(surveys_complete,
       aes(x = species_id,
           y = weight)) +
  geom_boxplot() + 
  geom_jitter(alpha = 0.2)

ggplot(surveys_complete,
       aes(x = species_id,
           y = weight)) +
  geom_jitter(alpha = 0.2) +
  geom_boxplot()


ggplot(surveys_complete,
       aes(x = species_id,
           y = weight)) +
  geom_boxplot()

## remplacer les boxplots par des violin plots
## avec le geom_violin()

ggplot(surveys_complete,
       aes(x = species_id,
           y = weight)) +
  geom_violin()

## transformer les donnees weigth en log10 avec 
## scale_y_log10()

ggplot(surveys_complete,
       aes(x = species_id,
           y = weight)) +
  geom_violin() + 
  scale_y_log10()


## times series
yearly_count <- surveys_complete %>% 
  count(year, species_id)

yearly_count %>% 
  filter(species_id == "OL")


ggplot(yearly_count, 
       aes(x = year,
           y = n,
           group = species_id)) +
  geom_line()

ggplot(yearly_count, 
       aes(x = year,
           y = n,
           colour = species_id)) +
  geom_line()


## facetting

ggplot(yearly_count, 
       aes(x = year,
           y = n)) +
  geom_line() + 
  facet_wrap(~ species_id)

ggplot(yearly_count, 
       aes(x = year,
           y = n,
           colour = species_id)) +
  geom_line() + 
  facet_wrap(~ species_id)

## count the number of species by year
## AND by sex.

yearly_sex_count <- surveys_complete %>% 
  count(year, sex, species_id)

p2 <- ggplot(yearly_sex_count,
       aes(x = year,
           y = n,
           colour = sex)) +
  geom_line() + 
  facet_wrap(~ species_id)

ggplot(yearly_sex_count,
       aes(x = year,
           y = n,
           colour = sex)) +
  geom_line() + 
  facet_grid(sex ~ species_id)

p2

## composition

p <- p + geom_point()
p

library(patchwork)

p + p2

p3 <- p / p2

## exporting figures

ggsave("figs/fig1.pdf")
ggsave("figs/fig2.png")
ggsave("figs/fig4.pdf", p3)
